@@ -6,8 +6,8 @@
 ;; Maintainer: Bozhidar Batsov <bozhidar@batsov.dev>
 ;; URL: http://github.com/bbatsov/neocaml
 ;; Keywords: languages ocaml ml
-;; Package-Version: 20260218.745
-;; Package-Revision: 8db3894f034a
+;; Package-Version: 20260225.1322
+;; Package-Revision: 6ee2fcb1a9f1
 ;; Package-Requires: ((emacs "29.1"))
 
 ;; This file is not part of GNU Emacs.
@@ -260,7 +260,8 @@ The return value is suitable for `treesit-font-lock-settings'."
    :feature 'keyword
    `([,@neocaml-mode--keywords] @font-lock-keyword-face
      (fun_expression "->" @font-lock-keyword-face)
-     (match_case "->" @font-lock-keyword-face))
+     (match_case "->" @font-lock-keyword-face)
+     (value_definition [(let_operator) (let_and_operator)] @font-lock-keyword-face))
 
    ;; See https://ocaml.org/manual/5.3/attributes.html
    ;; and https://ocaml.org/manual/5.3/extensionnodes.html
@@ -836,13 +837,47 @@ was in a comment, nil otherwise to let the default handler run."
             (when (looking-at "(\\*+[ \t]*")
               (setq start (match-end 0)))
             (goto-char end)
-            (when (looking-back "[ \t]*\\*+)" nil)
-              (setq end (match-beginning 0)))
-            (narrow-to-region start end)
-            (let ((fill-paragraph-function nil))
+            (when (looking-back "\\*+)" nil)
+              (goto-char (match-beginning 0))
+              (skip-chars-backward " \t")
+              (setq end (point)))
+            ;; Compute fill-prefix from body start column so
+            ;; continuation lines are indented to align with text
+            ;; after the opening delimiter.
+            (goto-char start)
+            (let* ((body-col (current-column))
+                   (fill-prefix (make-string body-col ?\s))
+                   (fill-paragraph-function nil))
+              (narrow-to-region start end)
               (fill-paragraph nil))
             t))))))
 
+;;;; Comment continuation (M-j)
+
+(defun neocaml--comment-body-column ()
+  "Return the column where comment body text starts, or nil."
+  (let* ((node (treesit-node-at (point)))
+         (comment (treesit-parent-until
+                   node
+                   (lambda (n) (equal (treesit-node-type n) "comment"))
+                   t)))
+    (when comment
+      (save-excursion
+        (goto-char (treesit-node-start comment))
+        (when (looking-at "(\\*+[ \t]*")
+          (goto-char (match-end 0))
+          (current-column))))))
+
+(defun neocaml--comment-indent-new-line (&optional soft)
+  "Break line at point and indent, continuing comment if within one.
+SOFT works the same as in `comment-indent-new-line'."
+  (let ((body-col (neocaml--comment-body-column)))
+    (if body-col
+        (progn
+          (if soft (insert-and-inherit ?\n) (newline 1))
+          (insert-char ?\s body-col))
+      (comment-indent-new-line soft))))
+
 ;;;; Utility commands
 
 (defconst neocaml-report-bug-url "https://github.com/bbatsov/neocaml/issues/new"
@@ -945,7 +980,8 @@ for .ml files and `neocaml-interface-mode' for .mli files."
   (setq-local comment-start "(* ")
   (setq-local comment-end " *)")
   (setq-local comment-start-skip "(\\*+[ \t]*")
-  (setq-local comment-end-skip "[ \t]*\\*+)")
+  (setq-local comment-multi-line t)
+  (setq-local comment-line-break-function #'neocaml--comment-indent-new-line)
 
   ;; Electric indentation on delimiters
   (setq-local electric-indent-chars
